# Streamlit Image Crop

A [Streamlit](https://www.streamlit.io/) component based on [React Image Crop](https://github.com/DominicTobias/react-image-crop).

![Screenshot](https://raw.githubusercontent.com/mitsuse/streamlit-image-crop/master/screenshot.png)

## Installation

```
pip install streamlit-image-crop
```

## Example

Try [example.py](https://github.com/mitsuse/streamlit-image-crop/blob/master/example.py).

First, you need to install dependencies:

```
git clone https://github.com/mitsuse/streamlit-image-crop.git && cd streamlit-image-crop
pip install poetry
poetry install
```

Next, run `react-script start`:

```
cd streamlit-image-crop/frontend/ && npm run start
```

Finally, run the example:

```
poetry run streamlit run example.py
```

## License

Streamlit Image Crop is licensed under the ISC license.
Please read [LICENSE](https://github.com/mitsuse/streamlit-image-crop/blob/master/LICENSE) for the detail.
